@@ -45,8 +45,11 @@ class Enough(object):
         return r
 
     def update_internal_subnet_dns(self):
+        self.hosts.load()
         if not self.hosts.get_ip('bind-host'):
+            log.info('do not update internal dns because bind-host does not exist')
             return
+        log.info('update internal network dns server with bind-host IP address')
         dns = []
         for host in self.service.service2hosts['bind']:
             dns.append(self.openstack.server_ip_in_network(host, self.openstack.INTERNAL_NETWORK))
