@@ -12,29 +12,44 @@ log = logging.getLogger(__name__)
 
 class Ansible(object):
 
-    def __init__(self, config_dir, share_dir):
+    def __init__(self, config_dir, share_dir, inventories=[]):
         self.config_dir = config_dir
         self.share_dir = share_dir
+        self.set_inventories(inventories)
 
-    def bake_ansible_playbook(self):
-        args = [
+    def set_inventories(self, inventories):
+        self.inventories = [
             '-i', 'inventory',
-            '-i', 'development-inventory',
-            '--extra-vars', f'enough_domain_config_directory={self.config_dir}',
         ]
         if self.config_dir != '.':
-            args.extend(['-i', f'{self.config_dir}/inventory'])
-            args.extend(['-i', f'{self.config_dir}/development-inventory'])
-        return sh.ansible_playbook.bake(
-            *args,
-            _tee=True,
-            _out=lambda x: log.info(x.strip()),
-            _err=lambda x: log.info(x.strip()),
+            self.inventories.extend(['-i', f'{self.config_dir}/inventory'])
+        if inventories:
+            self.inventories.extend([f'-i{i}' for i in inventories])
+
+    def bake_ansible_playbook(self, verbose=True):
+        args = [
+            '--extra-vars', f'enough_domain_config_directory={self.config_dir}',
+        ] + self.inventories
+        if self.vault_password_option():
+            args.append(self.vault_password_option())
+        kwargs = dict(
             _truncate_exc=False,
             _cwd=self.share_dir,
             _env={'ANSIBLE_NOCOLOR': 'true'},
         )
 
+        if verbose:
+            kwargs.update(dict(
+                _tee=True,
+                _out=lambda x: log.info(x.strip()),
+                _err=lambda x: log.info(x.strip()),
+            ))
+
+        return sh.ansible_playbook.bake(
+            *args,
+            **kwargs,
+        )
+
     def vault_password_option(self):
         password_file = f'{self.config_dir}.pass'
         if os.path.exists(password_file):
@@ -46,12 +61,7 @@ class Ansible(object):
     def ansible_inventory(self):
         args = [
             '--list',
-            '-i', 'inventory',
-            '-i', 'development-inventory',
-        ]
-        if self.config_dir != '.':
-            args.extend(['-i', f'{self.config_dir}/inventory'])
-            args.extend(['-i', f'{self.config_dir}/development-inventory'])
+        ] + self.inventories
         if self.vault_password_option():
             args.append(self.vault_password_option())
         i = sh.ansible_inventory(
@@ -75,32 +85,39 @@ class Ansible(object):
         return groups
 
     def get_variable(self, role, variable, host):
+        return self.get_variable_hosts(role, variable, host)[host]
+
+    def get_variable_hosts(self, role, variable, *hosts):
         with tempfile.NamedTemporaryFile() as f:
             # the sourrounding "> <" are to prevent conversion to int, list or whatever
             playbook = textwrap.dedent("""
             ---
             - hosts: all
               gather_facts: false
+              serial: 1
 
               roles:
                 - role: "{{ rolevar }}"
+                  when: false
 
               tasks:
                 - name: print variable
                   debug:
-                    msg: ">{{ variable }}<"
+                    msg: ">{{ ansible_play_batch[0] }}:{{ variable }}<"
             """)
             f.write(bytearray(playbook, 'utf-8'))
             f.flush()
-            print(playbook)
-            r = self.bake_ansible_playbook()(
+            args = [
                 '-e', f'rolevar={role}',
                 '-e', 'variable={{ ' + variable + ' }}',
-                '--limit', host,
-                '--start-at-task=print variable',
-                f.name)
-            m = re.search(r'"msg": ">(.*)<"$', r.stdout.decode('utf-8'), re.MULTILINE)
-            return m.group(1)
+                '--limit', ','.join(hosts),
+            ] + self.inventories + [
+                f.name
+            ]
+            r = self.bake_ansible_playbook(verbose=False)(*args)
+            return dict(re.findall(r'.*"msg": ">(.*?):(.*)<"$',
+                                   r.stdout.decode('utf-8'),
+                                   re.MULTILINE))
 
 
 class Playbook(Ansible):
@@ -148,8 +165,8 @@ class Playbook(Ansible):
 
     @staticmethod
     def roles_path(d):
-        r = glob.glob(f'{d}/molecule/*/roles')
-        r.append(f'{d}/molecule/wazuh/wazuh-ansible/roles/wazuh')
+        r = glob.glob(f'{d}/playbooks/*/roles')
+        r.append(f'{d}/playbooks/wazuh/wazuh-ansible/roles/wazuh')
         return ":".join(r)
 
     def bake(self):
@@ -161,7 +178,6 @@ class Playbook(Ansible):
             args.append(self.vault_password_option())
         if self.share_dir != self.config_dir:
             args.extend(['-i', f'{self.config_dir}/inventory'])
-            args.extend(['-i', f'{self.config_dir}/development-inventory'])
         logger = logging.getLogger(__name__)
         return sh.ansible_playbook.bake(
             *args,
