@@ -18,6 +18,13 @@ class Hosts(object):
             self.hosts = yaml.load(open(self.f).read())['all']['hosts']
         else:
             self.hosts = {}
+        return self
+
+    def get_ip(self, host):
+        return self.hosts.get(host, {}).get('ansible_host')
+
+    def get_port(self, host):
+        return self.hosts.get(host, {}).get('ansible_port', '22')
 
     def save(self):
         if not os.path.exists(self.d):
@@ -34,9 +41,9 @@ class Hosts(object):
     def missings(self, names):
         return [name for name in names if name not in self.hosts]
 
-    def create_or_update(self, name, ipv4):
-        if self.hosts.get(name, {}).get('ansible_host') != ipv4:
-            self.hosts[name] = {'ansible_host': ipv4}
+    def create_or_update(self, name, ipv4, port):
+        if self.get_ip(name) != ipv4:
+            self.hosts[name] = {'ansible_host': ipv4, 'ansible_port': port}
             self.save()
             return True
         else:
@@ -100,27 +107,6 @@ class DotEnough(object):
         certificate_authority: {certificate_authority}
         """))
 
-    @staticmethod
-    def remap(argv):
-        home = os.path.expanduser('~/.enough')
-
-        def remap(s):
-            s = re.sub(r'^/\S+/.enough', home, s)
-            s = re.sub(r'=/\S+/.enough', f'={home}', s)
-            return s
-        return [remap(a) for a in argv]
-
-    @staticmethod
-    def preserve_ownership():
-        uid = os.geteuid()
-        home = os.path.expanduser('~/.enough')
-        if not uid == 0 or not os.path.exists(home):
-            return False
-        home_uid = os.stat(home).st_uid
-        if uid != home_uid:
-            os.system(f'chown -R {home_uid} {home}')
-        return True
-
 
 class DotEnoughOpenStack(DotEnough):
 
