@@ -12,9 +12,10 @@ from enough.common import tcp
 
 class Host(ABC):
 
-    def __init__(self, config_dir, share_dir):
+    def __init__(self, config_dir, share_dir, **kwargs):
         self.config_dir = config_dir
         self.share_dir = share_dir
+        self.args = kwargs
 
     @abstractmethod
     def create_or_update(self):
@@ -76,13 +77,13 @@ class HostDocker(Host):
 class HostOpenStack(Host):
 
     def __init__(self, config_dir, share_dir, **kwargs):
-        super().__init__(config_dir, share_dir)
+        super().__init__(config_dir, share_dir, **kwargs)
         self.args = kwargs
         self.dotenough = dotenough.DotEnoughOpenStack(config_dir, self.args['domain'])
         self.dotenough.ensure()
 
     def create_or_update(self):
-        h = openstack.Heat(self.config_dir, self.args['clouds'])
+        h = openstack.Heat(self.config_dir, self.args['clouds'], **self.args)
         s = openstack.Stack(self.config_dir,
                             self.args['clouds'],
                             h.get_stack_definition(self.args['name']))
@@ -90,12 +91,22 @@ class HostOpenStack(Host):
         return s.create_or_update()
 
     def delete(self):
-        h = openstack.Heat(self.config_dir, self.args['clouds'])
-        for name in self.args['name']:
+        self.delete_hosts(self.args['name'])
+
+    def delete_hosts(self, names):
+        h = openstack.Heat(self.config_dir, self.args['clouds'], **self.args)
+        complete_deletion = []
+        for name in names:
             s = openstack.Stack(self.config_dir,
                                 self.args['clouds'],
                                 h.get_stack_definition(name))
-            s.delete()
+            if s.delete_no_wait():
+                complete_deletion.append(name)
+        for name in complete_deletion:
+            s = openstack.Stack(self.config_dir,
+                                self.args['clouds'],
+                                h.get_stack_definition(name))
+            s.delete_wait()
 
 
 def host_factory(config_dir=settings.CONFIG_DIR, share_dir=settings.SHARE_DIR, **kwargs):
