@@ -10,7 +10,8 @@ class CreateTestSubdomain(ShowOne):
 
     def take_action(self, parsed_args):
         clouds_file = f'{settings.CONFIG_DIR}/inventory/group_vars/all/clouds.yml'
-        r = openstack.Heat(clouds_file).create_test_subdomain(self.app.options.domain)
+        h = openstack.Heat(settings.CONFIG_DIR, clouds_file)
+        r = h.create_test_subdomain(self.app.options.domain)
         columns = ('name',)
         data = (r,)
         return (columns, data)
