@@ -6,14 +6,31 @@ from enough import settings
 from enough.common import ansible_utils
 
 
-def test_get_variable():
-    defaults = yaml.load(open('molecule/api/roles/api/defaults/main.yml'))
+def test_get_variable_no_arg():
+    defaults = yaml.load(open('playbooks/api/roles/api/defaults/main.yml'))
     variable = 'api_admin_password'
     ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR)
     value = ansible.get_variable('api', variable, 'api-host')
     assert defaults[variable] == value
 
 
+def test_get_variable_hosts():
+    ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR)
+    d = ansible.get_variable_hosts('authorized_keys', 'production_domain',
+                                   'bind-host', 'icinga-host')
+    assert d == {'bind-host': 'enough.community', 'icinga-host': 'enough.community'}
+
+
+def test_get_variable_inventory():
+    test_inventory = 'tests/enough/common/test_ansible_utils/variables_inventory'
+    expected = yaml.load(open(f'{test_inventory}/host_vars/api-host.yml'))
+    variable = 'api_admin_password'
+    ansible = ansible_utils.Ansible(settings.CONFIG_DIR, settings.SHARE_DIR)
+    ansible.set_inventories([test_inventory])
+    value = ansible.get_variable('api', variable, 'api-host')
+    assert expected[variable] == value
+
+
 def test_playbook_roles_path():
     p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
     r = p.roles_path('.')
@@ -51,10 +68,9 @@ def test_playbook_ensure_decrypted(tmpdir):
     assert p.ensure_decrypted() is False
 
 
-def test_playbook_run_with_args(capsys, caplog):
+def test_playbook_run_with_args(caplog):
     p = ansible_utils.Playbook(settings.CONFIG_DIR, settings.SHARE_DIR)
     p.run('tests/enough/common/test_ansible_utils/playbook-ok.yml')
-    out, err = capsys.readouterr()
     assert 'OK_PLAYBOOK' in caplog.text
     assert 'OK_IMPORTED' in caplog.text
 
