@@ -109,9 +109,11 @@ def test_create_copy_host(tmpdir):
         if 'copy-volume' not in enough.openstack.o.volume.list():
             enough.openstack.o.volume.create('--size', '1', 'copy-volume')
         ip = enough.create_copy_host('copy-from-host', 'some-volume', 'copy-volume')
-        r = sh.ssh('-i', enough.dotenough.private_key(), f'root@{ip}', 'id')
+        r = sh.ssh('-oStrictHostKeyChecking=no',
+                   '-i', enough.dotenough.private_key(), f'root@{ip}', 'id')
         assert 'uid=0(root)' in r
-        r = sh.ssh('-i', enough.dotenough.private_key(), f'root@{ip}', 'mountpoint', '/srv').strip()
+        r = sh.ssh('-oStrictHostKeyChecking=no',
+                   '-i', enough.dotenough.private_key(), f'root@{ip}', 'mountpoint', '/srv').strip()
         assert r == '/srv is a mountpoint'
     finally:
         o = OpenStack(settings.CONFIG_DIR, clouds)
@@ -130,8 +132,10 @@ def test_clone_volume_from_snapshot(tmpdir):
         original.set_args(name='sample', playbook='enough-playbook.yml')
         original.service.create_or_update()
         ip = original.hosts.load().get_ip('sample-host')
-        sh.ssh('-i', original.dotenough.private_key(), f'debian@{ip}', 'touch', '/srv/STONE')
-        sh.ssh('-i', original.dotenough.private_key(), f'debian@{ip}', 'sync')
+        sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', original.dotenough.private_key(), f'debian@{ip}', 'touch', '/srv/STONE')
+        sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', original.dotenough.private_key(), f'debian@{ip}', 'sync')
         original.openstack.backup_create(['sample-volume'])
         snapshot = f'{original.openstack.backup_date()}-sample-volume'
         assert snapshot in original.openstack.o.volume.snapshot.list()
@@ -142,12 +146,15 @@ def test_clone_volume_from_snapshot(tmpdir):
         (from_ip, to_ip, from_volume, to_volume) = original._clone_volume_from_snapshot_body(
             clone, snapshot)
 
-        assert sh.ssh('-i', original.dotenough.private_key(), f'root@{from_ip}',
+        assert sh.ssh('-oStrictHostKeyChecking=no',
+                      '-i', original.dotenough.private_key(), f'root@{from_ip}',
                       'test', '-e', '/srv/STONE').exit_code == 0
-        assert sh.ssh('-i', clone.dotenough.private_key(), f'root@{to_ip}',
+        assert sh.ssh('-oStrictHostKeyChecking=no',
+                      '-i', clone.dotenough.private_key(), f'root@{to_ip}',
                       'test', '!', '-e', '/srv/STONE').exit_code == 0
         original._rsync_copy_host(from_ip, to_ip)
-        assert sh.ssh('-i', clone.dotenough.private_key(), f'root@{to_ip}',
+        assert sh.ssh('-oStrictHostKeyChecking=no',
+                      '-i', clone.dotenough.private_key(), f'root@{to_ip}',
                       'test', '-e', '/srv/STONE').exit_code == 0
 
         original._clone_volume_from_snapshot_cleanup(clone, from_volume)
@@ -188,7 +195,8 @@ def test_restore_remote(tmpdir):
         original.service.create_or_update()
         ip = original.hosts.load().get_ip('sample-host')
 
-        sh.ssh('-i', original.dotenough.private_key(), f'debian@{ip}', 'touch', '/srv/STONE')
+        sh.ssh('-oStrictHostKeyChecking=no',
+               '-i', original.dotenough.private_key(), f'debian@{ip}', 'touch', '/srv/STONE')
         original.openstack.backup_create(['sample-volume'])
         snapshot = f'{original.openstack.backup_date()}-sample-volume'
         assert snapshot in original.openstack.o.volume.snapshot.list()
@@ -197,7 +205,8 @@ def test_restore_remote(tmpdir):
         assert 'sample-volume' in clone.openstack.o.volume.list()
         hosts = clone.hosts.load()
         Stack.wait_for_ssh(hosts.get_ip('sample-host'), hosts.get_port('sample-host'))
-        assert sh.ssh('-i', clone.dotenough.private_key(), f'debian@{ip}',
+        assert sh.ssh('-oStrictHostKeyChecking=no',
+                      '-i', clone.dotenough.private_key(), f'debian@{ip}',
                       'test', '-e', '/srv/STONE').exit_code == 0
 
     finally:
