@@ -2,7 +2,7 @@
 
 # ENOUGH_API_TOKEN=abc tests/run-tests.sh tox -e openvpn -- --enough-no-create --enough-no-tests playbooks/openvpn/tests
 
-set -ex
+set -e
 
 function prepare_environment() {
     if test $(id -u) != 0 ; then
@@ -10,6 +10,11 @@ function prepare_environment() {
     fi
     $SUDO apt-get update
     $SUDO apt-get install -y git
+    if test -d ~/.ansible ; then
+        $SUDO chown -R $(id -u) ~/.ansible
+    fi
+    git submodule update --init --recursive
+    chmod 600 infrastructure_key
 }
 
 function prepare_inventory() {
@@ -27,6 +32,7 @@ clouds:
       password: "$OS_PASSWORD"
     region_name: "$OS_REGION_NAME"
 EOF
+        cp tests/clouds.yml inventory/group_vars/all/clouds.yml
     else
         cat inventory/group_vars/all/clouds.yml > tests/clouds.yml
     fi
@@ -36,6 +42,7 @@ EOF
 ---
 domain: enough.community
 EOF
+        cp tests/domain.yml inventory/group_vars/all/domain.yml
     else
         cat inventory/group_vars/all/domain.yml > tests/domain.yml
     fi
@@ -52,11 +59,12 @@ function image_name() {
 
 function build_image() {
     local name="$1"
+    local max_execution_time="$2"
 
     (
         cat enough/common/data/base.dockerfile
         cat tests/tox.dockerfile
-    ) | docker build --build-arg=USER_ID="$(id -u)" --build-arg=DOCKER_GID="$(getent group docker | cut -d: -f3)" --build-arg=USER_NAME="${USER:-root}" --tag $name -f - .
+    ) | timeout $max_execution_time docker build --build-arg=USER_ID="$(id -u)" --build-arg=DOCKER_GID="$(getent group docker | cut -d: -f3)" --build-arg=USER_NAME="${USER:-root}" --tag $name -f - .
 }
 
 function run_tests_on_ref() {
@@ -99,13 +107,17 @@ function run_tests() {
     shift
 
     find $d \( -name '*.pyc' -o -name '*.pyo' -o -name __pycache__ \) -delete
+    skip=""
     if test "$SKIP_OPENSTACK_INTEGRATION_TESTS" ; then
-        skip="-e SKIP_OPENSTACK_INTEGRATION_TESTS=true"
+        skip+="-e SKIP_OPENSTACK_INTEGRATION_TESTS=true "
+    fi
+    if test "$SKIP_NETWORK_OPENSTACK_INTEGRATION_TESTS" ; then
+        skip+="-e SKIP_NETWORK_OPENSTACK_INTEGRATION_TESTS=true "
     fi
     if test "$GITLAB_CI" ; then
         args="--workdir /opt"
     else
-        args="--volume ${d}:${d} --workdir ${d} --volume $HOME/.enough:$HOME/.enough"
+        args="--volume ${d}:${d} --workdir ${d} --volume $HOME/.enough:$HOME/.enough --volume $HOME/.ansible:$HOME/.ansible -e HOME=$HOME"
     fi
     docker run --rm --device=/dev/net/tun --name $name --user "${USER:-root}" -e ENOUGH_API_TOKEN=$ENOUGH_API_TOKEN $skip --cap-add=NET_ADMIN $args --volume /var/run/docker.sock:/var/run/docker.sock $name "${@:-tox}"
 }
@@ -114,7 +126,9 @@ function main() {
     prepare_environment
     prepare_inventory
     local name=$(image_name "$@")
-    build_image $name
+    echo -n Creating or refreshing the docker image to run the tests...
+    build_image $name 15 < /dev/null > /dev/null 2>&1 || build_image $name 7200
+    echo done!
     local toplevel=$(git rev-parse --show-toplevel)
     if test "$1" = "--upgrade" ; then
         shift
